@@ -27,10 +27,12 @@
 #include <QSharedPointer>
 
 class SnapBackend;
+class QAbstractItemModel;
 
 class SnapResource : public AbstractResource
 {
 Q_OBJECT
+Q_PROPERTY(QStringList objects MEMBER m_objects CONSTANT)
 public:
     explicit SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend* parent);
     ~SnapResource() override = default;
@@ -42,12 +44,11 @@ public:
     QString installedVersion() const override;
     QString license() override;
     int size() override;
-    QUrl homepage() override;
     QStringList categories() override;
-    AbstractResource::State state() const override;
+    AbstractResource::State state() override;
     QVariant icon() const override;
     QString comment() override;
-    QString name() override;
+    QString name() const override;
     QString packageName() const override;
     bool isTechnical() const override;
     bool canExecute() const override { return true; }
@@ -59,6 +60,11 @@ public:
     void setSnap(const QSharedPointer<QSnapdSnap> &snap);
 
     void setState(AbstractResource::State state);
+    QString sourceIcon() const override { return QStringLiteral("snap"); }
+
+    QDate releaseDate() const override;
+
+    Q_SCRIPTABLE QAbstractItemModel* plugs(QObject* parents);
 
 public:
     void gotIcon();
@@ -66,6 +72,7 @@ public:
 
     QSharedPointer<QSnapdSnap> m_snap;
     mutable QVariant m_icon;
+    const QStringList m_objects;
 };
 
 #endif // SNAPRESOURCE_H
